==> cloudstructs-0.4.16.tar.gz: package/assets/email-receiver/whitelist.lambda/index.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __reExport = (target, module2, copyDefault, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && (copyDefault || key !== "default"))
        __defProp(target, key, { get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable });
  }
  return target;
};
var __toCommonJS = /* @__PURE__ */ ((cache) => {
  return (module2, temp) => {
    return cache && cache.get(module2) || (temp = __reExport(__markAsModule({}), module2, 1), cache && cache.set(module2, temp), temp);
  };
})(typeof WeakMap !== "undefined" ? /* @__PURE__ */ new WeakMap() : 0);

// src/email-receiver/whitelist.lambda.ts
var whitelist_lambda_exports = {};
__export(whitelist_lambda_exports, {
  handler: () => handler
});
async function handler(event) {
  console.log("Event: %j", event);
  const sesNotification = event.Records[0].ses;
  if (!process.env.SOURCE_WHITELIST) {
    console.log("Missing SOURCE_WHITELIST");
    return { disposition: "STOP_RULE" };
  }
  if (!new RegExp(process.env.SOURCE_WHITELIST).test(sesNotification.mail.source)) {
    console.log(`${sesNotification.mail.source} does not match /${process.env.SOURCE_WHITELIST}/`);
    return { disposition: "STOP_RULE" };
  }
  return { disposition: "CONTINUE" };
}
module.exports = __toCommonJS(whitelist_lambda_exports);
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});

==> cloudstructs-0.4.28.tar.gz: package/assets/email-receiver/whitelist.lambda/index.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/email-receiver/whitelist.lambda.ts
var whitelist_lambda_exports = {};
__export(whitelist_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(whitelist_lambda_exports);
async function handler(event) {
  console.log("Event: %j", event);
  const sesNotification = event.Records[0].ses;
  if (!process.env.SOURCE_WHITELIST) {
    console.log("Missing SOURCE_WHITELIST");
    return { disposition: "STOP_RULE" };
  }
  if (!new RegExp(process.env.SOURCE_WHITELIST).test(sesNotification.mail.source)) {
    console.log(`${sesNotification.mail.source} does not match /${process.env.SOURCE_WHITELIST}/`);
    return { disposition: "STOP_RULE" };
  }
  return { disposition: "CONTINUE" };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
